'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = edit;

var _phone = require('./phone');

// Edits <input/>ted value according to the input conditions (caret position, key pressed)
//
// value          - '  999) 123 45 -67'
// caret_position - 5 // starting from 0
// format         - { city: 3, number: [3, 2, 2] }
//
// options:
// {
// 	delete: false,
// 	backspace: false,
// 	selection: { start: 123, end: 456 } // `end` specifies the index of the character after the selection
// }
//
// Returns
// {
// 	phone: '(999) 123-45'
// 	caret: 12 // starting from 0
// }
//
function edit(value, caret_position, format) {
	var options = arguments.length <= 3 || arguments[3] === undefined ? {} : arguments[3];

	if (options.selection && options.backspace) {
		options.backspace = false;
		options.delete = true;
	}

	// Phone number digits (may be altered later)
	var digits = (0, _phone.digits)(value, format);

	// Generate phone number template based on the phone format structure.
	// e.g. { code: '7', city: 3, number: [3, 2, 2] } -> '(xxx) xxx-xx-xx'
	var template = (0, _phone.template)(format);

	// Adjust caret position
	if (options.backspace) {
		// Find the closest previous digit
		var previous_digit_index = (0, _phone.digit_index)(value, caret_position) - 1;
		if (previous_digit_index < 0) {
			// Adjust caret position
			caret_position = (0, _phone.index_in_template)(0, format);
		} else {
			var digits_in_phone_number = (0, _phone.digits_in_number)(format);
			if (previous_digit_index < digits_in_phone_number) {
				// Remove the previous digit
				digits = digits.substring(0, previous_digit_index) + digits.substring(previous_digit_index + 1);
				// Adjust caret position
				caret_position = (0, _phone.index_in_template)(previous_digit_index, format);
			} else {
				// Adjust caret position
				caret_position = (0, _phone.index_in_template)(digits_in_phone_number - 1, format) + 1;
			}
		}
	} else if (options.delete) {
		if (options.selection) {
			var digit_index = (0, _phone.digit_index)(value, options.selection.start);

			value = value.substring(0, options.selection.start) + value.substring(options.selection.end);
			digits = (0, _phone.digits)(value, format);

			// Adjust caret position
			caret_position = (0, _phone.index_in_template)(digit_index, format);
		} else {
			// Find current digit
			var _digit_index = (0, _phone.digit_index)(value, caret_position);
			var _digits_in_phone_number = (0, _phone.digits_in_number)(format);
			if (_digit_index < _digits_in_phone_number) {
				// Remove current digit
				digits = digits.substring(0, _digit_index) + digits.substring(_digit_index + 1);
				// Adjust caret position
				caret_position = (0, _phone.index_in_template)(_digit_index, format);
			} else {
				// Position the caret after the last digit in phone number
				caret_position = (0, _phone.index_in_template)(_digits_in_phone_number - 1, format) + 1;
			}
		}
	} else {
		// Find the digit after the last inserted (keydowned, pasted, etc) digit
		var next_digit_index = (0, _phone.digit_index)(value, caret_position);

		// Adjust caret position
		var _digits_in_phone_number2 = (0, _phone.digits_in_number)(format);
		if (next_digit_index < _digits_in_phone_number2) {
			// Position the caret at the next digit
			caret_position = (0, _phone.index_in_template)(next_digit_index, format);
		} else {
			// Position the caret after the last digit in phone number
			caret_position = (0, _phone.index_in_template)(_digits_in_phone_number2 - 1, format) + 1;
		}
	}

	return { phone: (0, _phone.format)(digits, format), caret: caret_position };
}
module.exports = exports['default'];
//# sourceMappingURL=editor.js.map